evaluix
=======

.. image:: https://img.shields.io/badge/version-1.0.0-blue
   :target: https://img.shields.io/badge/version-1.0.0-blue
.. image:: https://img.shields.io/badge/License-MIT-blue
   :target: https://github.com/exp4-age/evaluix/blob/main/LICENSE

Data Evaluation Software of Arbeitsgruppe Ehresmann (Magnetism)
